@@ -395,7 +395,8 @@ class WitterUI():
         #self.treeview.connect("button-press-event", self.build_menu, None);
         selection = self.treeview.get_selection()
         #selection.connect('changed', self.build_menu)
-        self.treeview.connect('row-activated', self.build_menu)
+        #self.treeview.connect('row-activated', self.build_menu)
+        self.treeview.connect('row-activated', self.build_stacked_menu)
 
         self.window.show_all()
         self.window.connect("key-press-event", self.on_key_press)
@@ -755,29 +756,37 @@ class WitterUI():
     def build_stacked_menu(self, widget, *args):
         #first hide the other controls
         print "building stacked menu"
-
-        hbox1 = gtk.HButtonBox()
+        win = hildon.StackableWindow()
+        win.set_title("tweet")
+        vbox1 = gtk.VBox()
+        hboxTweet = gtk.HBox()
+        hbox0 = gtk.HBox()
+        hbox1 = gtk.HBox()
+        hbox2 = gtk.HBox()
         #empty the dynamic buttons
-        buttons = self.builder.get_object("hbuttonbox-act3").get_children()
-        for button in buttons:
-            self.builder.get_object("hbuttonbox-act3").remove(button)
-            button.destroy()
-        buttons2 = self.builder.get_object("hbuttonbox-act4").get_children()
-        for button in buttons2:
-            self.builder.get_object("hbuttonbox-act4").remove(button)
-            button.destroy()
-        #we need to track how many buttons we create
-        #so we know when to create new horizontal button boxes
-        b = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
-                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        #b.set_title('Dismiss')
-        disImage = gtk.Image()
-        disImage.set_from_file("/opt/witter/icons/dismiss.png")
-        disImage.show()
-        b.set_image(disImage)
-        b.connect("clicked", self.dismissActionButtons)
-        self.builder.get_object("hbuttonbox-act4").pack_end(b, expand=True)
 
+        #add avatar image and the tweet selected
+        # then all the associated action buttons
+        #standard buttons
+        #reply
+        reply = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        reply.set_title('Reply')
+        reply.connect("clicked", self.controller.replyTo)
+        hbox0.pack_start(reply, expand=True)
+        #reply_all
+        reply_all = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        reply_all.set_title('Reply All')
+        reply_all.connect("clicked", self.controller.replyAll)
+        hbox0.pack_start(reply_all, expand=True)
+
+        #direct message
+        dm = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
+                                                  hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        dm.set_title('Direct Message')
+        dm.connect("clicked", self.controller.directMessage)
+        hbox0.pack_start(dm, expand=True)
 
         #get the selection
         treeselection = self.treeview.get_selection()
@@ -797,6 +806,17 @@ class WitterUI():
                     entry = select1.get_value(select1.get_iter(item), 2)
                     #and we might as well list the person who provided the url
                     name = select1.get_value(select1.get_iter(item), 0)
+                    picture = select1.get_value(select1.get_iter(item), 9)
+                    picture = picture.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
+                    pic = gtk.Image()
+                    pic.set_from_pixbuf(picture)
+                    hboxTweet.pack_start(pic, expand=False)
+                    label = gtk.Label()
+                    label.set_text(select1.get_value(select1.get_iter(item), 10))
+                    label.set_use_markup(True)
+                    label.set_line_wrap(True)
+                    hboxTweet.pack_start(label, expand=True)
+
                     id = select1.get_value(select1.get_iter(item), 4)
                     selectedItem = item
                     #exclude logged in user from the reply_all string
@@ -818,7 +838,7 @@ class WitterUI():
                                 b.set_title('Open Url')
                                 b.set_value(url)
                                 b.connect("clicked", self.controller.openBrowser, url)
-                                self.builder.get_object("hbuttonbox-act3").pack_start(b, expand=True)
+                                hbox1.pack_start(b, expand=True)
                     if re.search("@", entry):
                         L = string.split(entry)
                         for word in L :
@@ -834,20 +854,20 @@ class WitterUI():
                                     b.set_title('Follow')
                                     b.set_value(user)
                                     b.connect("clicked", self.controller.activeAccount.FollowUser, user)
-                                    self.builder.get_object("hbuttonbox-act4").pack_start(b, expand=True)
+                                    hbox1.pack_start(b, expand=True)
                                     b2 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
 
                                     b2.set_value(user)
                                     b2.connect("clicked", self.controller.tweetAtUser, user)
-                                    self.builder.get_object("hbuttonbox-act4").pack_start(b2, expand=True)
+                                    hbox1.pack_start(b2, expand=True)
                                     b3 = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
 
                                     b3.set_title('History')
                                     b3.set_value(user)
                                     b3.connect("clicked", self.controller.showHist, user)
-                                    self.builder.get_object("hbuttonbox-act4").pack_start(b3, expand=True)
+                                    hbox1.pack_start(b3, expand=True)
 
 
                     #rect = self.treeview.get_background_area(item, self.tvctweet)
@@ -860,19 +880,19 @@ class WitterUI():
                     followButton.set_title('Follow')
                     followButton.set_value(name)
                     followButton.connect("clicked", self.controller.activeAccount.FollowUser, name)
-                    self.builder.get_object("hbuttonbox-act3").pack_start(followButton, expand=True)
+                    hbox2.pack_start(followButton, expand=True)
                 unfollowButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
                 unfollowButton.set_title('unFollow')
                 unfollowButton.set_value(name)
                 unfollowButton.connect("clicked", self.controller.activeAccount.UnFollowUser, name)
-                self.builder.get_object("hbuttonbox-act3").pack_start(unfollowButton, expand=True)
+                hbox2.pack_start(unfollowButton, expand=True)
                 histButton = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT,
                                                       hildon.BUTTON_ARRANGEMENT_VERTICAL)
                 histButton.set_title('History')
                 histButton.set_value(name)
                 histButton.connect("clicked", self.controller.showHist, name)
-                self.builder.get_object("hbuttonbox-act3").pack_start(histButton, expand=True)
+                hbox2.pack_start(histButton, expand=True)
 
                 self.builder.get_object("AtUser").set_label(name)
 
@@ -886,11 +906,13 @@ class WitterUI():
         except IndexError:
             print "nothing selected"
 
-        self.builder.get_object("hbuttonbox-act1").show_all()
-        self.builder.get_object("hbuttonbox-act2").show_all()
-        self.builder.get_object("hbuttonbox-act3").show_all()
-        self.builder.get_object("hbuttonbox-act4").show_all()
-        self.scrollToItem(selectedItem)
+        vbox1.pack_start(hboxTweet, expand=False)
+        vbox1.pack_start(hbox0, expand=False)
+        vbox1.pack_start(hbox1, expand=False)
+        vbox1.pack_start(hbox2, expand=False)
+        win.add(vbox1)
+        win.show_all()
+
 
     def scrollToItem(self, item):
         try:
@@ -924,7 +946,9 @@ class WitterUI():
         self.builder.get_object("hbuttonbox-act4").hide_all()
         self.builder.get_object("hbox2").show_all()
     def hideActionButtons(self):
-        self.dismissActionButtons()
+        stack = hildon.WindowStack.get_default()
+        stack.pop(1)
+        #self.dismissActionButtons()
     def showActionButtons(self):
         self.builder.get_object("hbuttonbox-act1").show_all()
         self.builder.get_object("hbuttonbox-act2").show_all()
